#
# spec file for package libhandy0
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib %{_name}-0_0-0
#define with_glade 1

Name:           libhandy0
%define _name   libhandy
Version:        0.0.13
Release:        bp155.2.18
Summary:        A GTK+ library to develop UI for mobile devices
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://source.puri.sm/Librem5/libhandy/
Source0:        %{_name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM libhandy-adapt-glade-3-36.patch -- Fix build with new glade 3.36
Patch0:         libhandy-adapt-glade-3-36.patch

BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.47.0
BuildRequires:  pkgconfig
BuildRequires:  vala
%if 0%{?with_glade}
BuildRequires:  pkgconfig(gladeui-2.0)
%endif
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.1

%description
libhandy is a library to help with developing UI for mobile devices
using GTK+/GNOME.

%package -n %{shlib}
Summary:        A GTK+ library to develop UI for mobile devices
Group:          System/Libraries

%description -n %{shlib}
This package provides the shared library for libhandy, a library to
help with developing mobile UI using GTK+/GNOME.

%package devel
Summary:        Source and header files for %{name}
Group:          Development/Libraries/GNOME
Requires:       %{shlib} = %{version}
Requires:       typelib-1_0-Handy-0_0 = %{version}
Conflicts:      %{_name}-devel

%description devel
This package provides the source and header files for writing
software using %{name}, a library to help with developing mobile UI
using GTK+/GNOME.

%package -n typelib-1_0-Handy-0_0
Summary:        Introspection bindings for libhandy
Group:          System/Libraries

%description -n typelib-1_0-Handy-0_0
This package provides the GObject Introspection bindings for
%{name}, a library to help with developing mobile UI using
GTK+/GNOME.

%package -n glade-catalog-libhandy0
Summary:        Glade catalog for libhandy
Group:          Development/Tools/GUI Builders
Requires:       glade
Supplements:    packageand(glade:%{name}-devel)
Conflicts:      glade-catalog-libhandy

%description -n glade-catalog-libhandy0
libhandy is a library to help with developing UI for mobile devices
using GTK+/GNOME.

This package provides a catalog for libhandy, to allow the use
libhandy widgets in Glade.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%meson \
	-Dprofiling=false \
	-Dstatic=false \
	-Dintrospection=enabled \
	-Dvapi=true \
	-Dgtk_doc=true \
	-Dtests=false \
	-Dexamples=false \
	-Dglade_catalog=%{?with_glade:enabled}%{?!with_glade:disabled} \
	%{nil}
%meson_build

%install
%meson_install

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/libhandy-*.so.*

%files devel
%license COPYING
%doc AUTHORS README.md
%{_includedir}/libhandy-0.0/
%{_libdir}/libhandy-*.so
%{_datadir}/gir-1.0/*.gir
%{_libdir}/pkgconfig/libhandy-0.0.pc
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libhandy-*
%{_datadir}/gtk-doc/html/libhandy/

%files -n typelib-1_0-Handy-0_0
%{_libdir}/girepository-1.0/*.typelib

%if 0%{?with_glade}
%files -n glade-catalog-libhandy0
%{_libdir}/glade/modules/*.so
%{_datadir}/glade/catalogs/*.xml
%endif

%changelog
* Sat Sep  5 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Disable glade catalogs for the time being: not compatible with
  glade 3.37.
* Tue Sep  1 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Rename to libhandy0, as libhandy moves to a newer version with a
  new ABI/API, but the world is only slowly catching up.
* Tue Aug 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Remove meson_build libhandy-doc call: it was a NOP and fails with
  meson 0.55.
* Fri May  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add libhandy-adapt-glade-3-36.patch: Fix build with new glade
  3.36.0.
* Fri Jan 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.13:
  + Various build and bug fixes.
* Thu Sep 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.11:
  + Various build and bug fixes.
- Switch to source service.
* Thu Jun 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.10:
  + Various build and bug fixes.
* Thu Mar  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.0.9:
  + Various build and bug fixes.
- Drop libhandy-fix-translations.patch: Fixed upstream.
* Fri Mar  1 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add libhandy-fix-translations.patch: Fix broken translations in
  apps using libhandy.
* Sat Feb 16 2019 bjorn.lie@gmail.com
- Update to version 0.0.8:
  + Various build and bug fixes, including a few memory leak fixes.
* Fri Jan 18 2019 bjorn.lie@gmail.com
- Update to version 0.0.7:
  + Various build and bug fixes.
  + Add introspection and the Glade catalog features.
  + Allow building as static lib.
  + Update documentation.
- Pass explicit options to meson, ensure we build the features we
  want and do not want.
* Mon Dec 24 2018 bjorn.lie@gmail.com
- Update to version 0.0.6:
  + Various buildfixes.
  + Reproduciable builds should now be possible.
  + Header bar cleanup.
- Changes from version 0.0.5:
  + meson: Properly depend on the generated headers.
  + Remove styles, depend on gtk to provide them.
- Drop libhandy-generated-header-dependency.patch: Fixed upstream.
* Fri Nov  9 2018 Jan Engelhardt <jengelh@inai.de>
- Update summary.
* Mon Nov  5 2018 badshah400@gmail.com
- Add libhandy-generated-header-dependency.patch: Fix dependency
  problems with headers generated by meson; fixes build for 32
  bit; patch taken from upstream git
  (https://source.puri.sm/Librem5/libhandy/issues/60).
- Enable parallel builds for i586.
* Wed Oct 31 2018 badshah400@gmail.com
- Use -j1 when building for i586, as parallel builds fail
  (https://source.puri.sm/Librem5/libhandy/issues/60).
* Wed Oct 31 2018 badshah400@gmail.com
- Initial package.
